jnigen library
This library exports a high level programmatic API to JNIgen, the entry point of which is the JniGenGenerator.generate method on a JniGenerator object.
Classes
- AndroidSdk
- Configuration for Android SDK sources and stub JAR files.
- ClassDecl
- Represents a Java class declaration.
- Classes
- A collection of class declarations.
- DartOutput
- Configuration for outputting generated Dart code.
- Field
- Represents a Java field declaration.
- Input
- Configuration for input Java source files, classpaths, and SDK dependencies.
- JniGenerator Java Differences Lifecycle Threading Interface Implementation Exceptions Java Runtime Types Debugging
- Configuration for JNIgen binding generation.
- MavenDownloads
- Configuration for dependencies to be downloaded using maven.
- Method
- Represents a Java method declaration.
- NullabilityAnnotations
- Custom nullability annotations configuration.
- Output
- Configuration for outputting generated Dart code and symbol files.
- Param
- Represents a Java parameter declaration.
- SymbolImports
-
Configuration for importing symbol files (
symbols.yaml) from other packages. - SymbolsOutput
- Configuration for outputting generated symbols YAML file.
- Visitor
- A visitor that can traverse the AST of Java elements.
Enums
- OutputStructure
- File structure of the generated Dart bindings.
- SummarizerBackend
- Backend for reading summary of Java libraries
Extensions
Functions
-
collectOutputStream(
Stream< List< stream, StringBuffer buffer) → voidint> > -
getOutputStructure(
String? name, OutputStructure defaultVal) → OutputStructure -
getSummarizerBackend(
String? name, SummarizerBackend? defaultVal) → SummarizerBackend?
Exceptions / Errors
- ConfigException
- Exception thrown when a configuration value is invalid.