NullabilityAnnotations class final

Custom nullability annotations configuration.

Constructors

NullabilityAnnotations({List<String> nonNull = const [], List<String> nullable = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
nonNull List<String>
Fully-qualified class names of custom @NonNull annotations.
final
nullable List<String>
Fully-qualified class names of custom @Nullable annotations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited