AndroidSdkTools class

Constructors

AndroidSdkTools()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAndroidJarPath({required Uri sdkRoot, required List<int> versionOrder}) Future<Uri?>
getAndroidSdkRoot() Uri
getGradleClasspaths({Uri? androidProject}) List<String>
Get release compile classpath used by Gradle for android build.
getGradleSources({Uri? androidProject}) List<String>
Get source paths for all gradle dependencies.