getGradleSources static method

List<String> getGradleSources({
  1. Uri? androidProject,
})

Get source paths for all gradle dependencies.

This function temporarily overwrites the build.gradle file by a stub with function to list all dependency paths for release variant. This function fails if no gradle build is attempted before.

Implementation

static List<String> getGradleSources({Uri? androidProject}) {
  return _runGradleStub(
    isSource: true,
    androidProject: androidProject ?? Uri.directory('.'),
  );
}