MavenDependency class

Maven dependency with group ID, artifact ID, and version.

Constructors

MavenDependency(String groupID, String artifactID, String version, {Map<String, String> otherTags = const {}})
MavenDependency.fromString(String fullName)
factory

Properties

artifactID ↔ String
getter/setter pair
groupID ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
otherTags ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String
getter/setter pair

Methods

filename({bool isSource = true}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGradleDependency(String configuration) → String
toString() → String
A string representation of this object.
inherited
toURLString(String repoLocation) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited