jnigen library Java Differences Lifecycle Threading Interface Implementation Debugging

This library exports a high level programmatic API to JNIgen, the entry point of which is the generateJniBindings function, which a Config object as a run configuration.

Enums

DeclKind
A kind describes the type of a declaration.
GenerationStage
The stage in the generation pipeline.
KmVariance
MethodKind
Operator
OutputStructure
SummarizerBackend
Backend for reading summary of Java libraries

Exceptions / Errors

ConfigException
Exception thrown when a configuration value is invalid.