jnigen library Java Differences Lifecycle Threading Interface Implementation Debugging
This library exports a high level programmatic API to JNIgen, the entry point of which is the generateJniBindings function, which a Config object as a run configuration.
Classes
- AndroidSdkConfig
- Configuration for Android SDK sources and stub JAR files.
- Annotation
- ArrayType
- ClassDecl
- Classes
- Config
- Configuration for JNIgen binding generation.
- DartCodeOutputConfig
- DeclaredType
-
Element<
T extends Element< T> > - Field
- JavaDocComment
- KotlinClass
- KotlinConstructor
- KotlinFunction
- KotlinPackage
- KotlinProperty
- KotlinType
- KotlinTypeArgument
- KotlinTypeParameter
- KotlinTypeProjection
- KotlinValueParameter
- KotlinWildcard
- MavenDownloads
- Configuration for dependencies to be downloaded using maven.
- Method
- OutputConfig
- Param
- PrimitiveType
- ReferredType
- SummarizerOptions
- Additional options to pass to the summary generator component.
- SymbolsOutputConfig
- ToArrayElement
- ToInnerClass
- ToTypeParam
- ToWildcardBound
- TypeParam
- TypePathStep
- TypeVar
- Wildcard
Enums
- DeclKind
- A kind describes the type of a declaration.
- GenerationStage
- The stage in the generation pipeline.
- KmVariance
- MethodKind
- Operator
- OutputStructure
- SummarizerBackend
- Backend for reading summary of Java libraries
Mixins
Functions
-
collectOutputStream(
Stream< List< stream, StringBuffer buffer) → voidint> > -
generateJniBindings(
Config config) → Future< void> -
getOutputStructure(
String? name, OutputStructure defaultVal) → OutputStructure -
getSummarizerBackend(
String? name, SummarizerBackend? defaultVal) → SummarizerBackend? -
typePathFromString(
String? string) → List< TypePathStep>
Exceptions / Errors
- ConfigException
- Exception thrown when a configuration value is invalid.