MavenDependency class

Maven dependency with group ID, artifact ID, and version.

Constructors

MavenDependency(String groupID, String artifactID, String version, {Map<String, String> otherTags = const {}})
MavenDependency.fromString(String fullName)
Parses a Maven dependency coordinate in groupID:artifactID:version format.
factory

Properties

artifactID ↔ String
Maven artifact ID.
getter/setter pair
groupID ↔ String
Maven group ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
javadocUrl → String
URL for browsing Javadoc documentation on javadoc.io.
no setter
otherTags ↔ Map<String, String>
Additional metadata tags for this dependency.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticJavadocUrl → String
URL for direct static Javadoc documentation on javadoc.io.
no setter
version ↔ String
Maven version.
getter/setter pair

Methods

filename({bool isSource = true}) → String
Returns the JAR filename for this dependency.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGradleDependency(String configuration) → String
Generates a Gradle dependency declaration string for configuration.
toString() → String
A string representation of this object.
inherited
toURLString(String repoLocation) → String
Resolves the full URL to the dependency artifact under repoLocation.

Operators

operator ==(Object other) → bool
The equality operator.
inherited